// -*-C++-*-
//
// File:      DalListViewAnyFile.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:21:17 MET DST 2000

#include "DalListViewAnyFile.h"
#include "DalListViewFolder.h"
#include "IconLibrary.h"
#include "DalListViewTable.h"
#include "DalListViewArray.h"

#include <qpixmap.h>

#include <iostream>

static const QPixmap* FileAnyXpm=0;
static const QPixmap* FileUnknownXpm=0;
static const QPixmap* DataSetXpm=0;

DalListViewAnyFile::DalListViewAnyFile(AnyFile* anyFile,
			   DalListViewFolder* parent,
			   const char* name)
  : DalListViewAttributable(0,parent,name),_anyFile(anyFile),
    _type(None)
{
  _init();
}

DalListViewAnyFile::DalListViewAnyFile(AnyFile* anyFile,
			   QListView* parent,
			   const char* name)
  :DalListViewAttributable(0,parent,name),_anyFile(anyFile),
   _type(None)
{
  _init();
}

DalListViewItem* DalListViewAnyFile::clone(QListView* parent)
{
  return new DalListViewAnyFile(_anyFile,parent,"Cloned");
}

void DalListViewAnyFile::_init()
{
  /* Initialise with Unknown */
  if (!FileAnyXpm) {
    FileAnyXpm=&IconLibrary::instance()->icon("FileAny.xpm");
    FileUnknownXpm=&IconLibrary::instance()->icon("FileUnknown.xpm");
    DataSetXpm=&IconLibrary::instance()->icon("DataSet.xpm");
  }    
    

  setText(0,_anyFile->name());
  setToType();
}

void DalListViewAnyFile::setToType()
{
  if (_anyFile->isParsed()) {
    if (_anyFile->dataSet()) {
      _type=DataSetType;
      setText(1,"DataSet");
      setPixmap(0,*DataSetXpm);
      setExpandable(false);
    }
    else {
      _type=FileType;
      setText(1,"File");
      setPixmap(0,*FileAnyXpm);
    }
  }
  else {
    setPixmap(0,*FileUnknownXpm);
    setText(1,"Unqualified");
  }
}

DalListViewAnyFile::~DalListViewAnyFile()
{
}


void DalListViewAnyFile::setOpen( bool o )
{
  /*
    std::cerr << "DalListViewAnyFile::setOpen(" << qualifiedName() << ")="
    << o << std::endl;
  */
  DataSet* dataSet=_anyFile->dataSet();
  setToType();
  if ( o && !childCount() && dataSet) {
    DataSet* dataSet=_anyFile->dataSet();
    _attributable=dataSet;
      
    unsigned nblocks = dataSet->blocks();
    for(unsigned i=0; i<nblocks; i++) {
      switch (dataSet->block(i)->type()) {
      case Block::TableT: 
	new DalListViewTable(dataSet->table(i),this);
	break;;
      case Block::ArrayT:
	new DalListViewArray(dataSet->array(i),this);
	break;;
      }
    }
  }
  QListViewItem::setOpen( o );
}

void DalListViewAnyFile::setup()
{
  setExpandable(true);
  QListViewItem::setup();
}


QString DalListViewAnyFile::qualifiedName()
{  
  return QString(_anyFile->qualifiedName());
}


void DalListViewAnyFile::openChildren(QListView* v)
{
  /*
    std::cerr << "DalListViewAnyFile::openChildren()" << std::endl;
  */
  if (!v) return;
  v->clear();
  
  DataSet* dataSet=_anyFile->dataSet();
  if (!dataSet) return;

  unsigned nblocks = dataSet->blocks();
  for(unsigned i=0; i<nblocks; i++) {
    switch (dataSet->block(i)->type()) {
    case Block::TableT: 
      new DalListViewTable(dataSet->table(i),v);
      break;;
    case Block::ArrayT:; // do nothing yet
      new DalListViewArray(dataSet->array(i),v);
      break;;
    }
  }
  _attributable=dataSet;
  DalListViewAttributable::openChildren(v);
}
