// -*-C++-*-
//
// File:      DalListViewTable.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:21:17 MET DST 2000

#include "DalListViewTable.h"
#include "DalListViewAnyFile.h"
#include "DalListViewColumn.h"
#include "IconLibrary.h"

#include <Dal.h>

#include <qpixmap.h>

#include <iostream>

static const QPixmap* TableXpm=0;

DalListViewTable::DalListViewTable(Table* table,
				   DalListViewAnyFile* parent,
				   const char* name)
  : DalListViewAttributable(table,parent,name),_table(table)
{
  _init();
}

DalListViewTable::DalListViewTable(Table* table,
				   QListView* parent,
				   const char* name)
  : DalListViewAttributable(table,parent,name),_table(table)
{
  _init();
}

DalListViewItem* DalListViewTable::clone(QListView* parent)
{
  return new DalListViewTable(_table,parent,"Cloned");
}

void DalListViewTable::_init()
{
  if (!TableXpm) TableXpm=&IconLibrary::instance()->icon("Table.xpm");

  QString txt(_table->name().c_str());
  setText(0,txt);
  setPixmap(0,*TableXpm);
  setText(1,"Table");
}

DalListViewTable::~DalListViewTable()
{
}

/* if we want columns in the tree. you have to set this */
const bool dalListViewTableExpandable=false;

void DalListViewTable::setOpen( bool o )
{
  if ( dalListViewTableExpandable && o && !childCount() ) {
      
    unsigned ncolumns = _table->columns();
    for(unsigned i=0; i<ncolumns; i++)
      new DalListViewColumn(_table->column(i),this);
  }
  QListViewItem::setOpen( o );
}

void DalListViewTable::setup()
{
  setExpandable(dalListViewTableExpandable);
  QListViewItem::setup();
}

QString DalListViewTable::qualifiedName()
{
  return QString(_table->qualifiedName().c_str());
}

void DalListViewTable::openChildren(QListView* v)
{
  v->clear();
  unsigned ncolumns = _table->columns();
  for(unsigned i=0; i<ncolumns; i++)
    new DalListViewColumn(_table->column(i),v);
  
  DalListViewAttributable::openChildren(v);
}
