// -*-C++-*-
//
// File:      DalQuickView.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul 31 11:41:32 MET DST 2000

#include "DalQuickView.h"
#include "DalListViewItem.h"
#include "DalListViewColumn.h"
#include "DalListViewArray.h"
#include "DalListViewAttribute.h"
#include "DalListViewHistory.h"
#include "DalListViewComment.h"
#include "DalViewAttribute.h"
#include "DalViewColumn.h"
#include "DalViewArray.h"
#include "DalViewText.h"

#include <Dal.h>

#include <qwidgetstack.h>
#include <qlayout.h>


DalQuickView::DalQuickView(QWidget* parent, const char* name) : 
  QWidget(parent,name),
  _layout(0),_child(0)
{
}

DalQuickView::~DalQuickView()
{
}


void DalQuickView::contentsOf(DalListViewItem* di)
{
  if (!di) return;

  if (_layout) {delete _layout;_layout=0;}
  if (_child)  {delete _child;_child=0;}

  _layout=new QVBoxLayout(this);

  DalListViewAttribute* attributeItem=dynamic_cast<DalListViewAttribute*>(di);
  if (attributeItem) {
    setContents(new DalViewAttribute(attributeItem->attribute(),this));
    return;
  }

  DalListViewColumn* columnItem=dynamic_cast<DalListViewColumn*>(di);
  if (columnItem) {
    setContents(new DalViewColumn(columnItem->column(),this));
    return;
  }
  
  DalListViewArray* arrayItem=dynamic_cast<DalListViewArray*>(di);
  if (arrayItem) {
    setContents(new DalViewArray(arrayItem->array(),this));
    return;
  }

  DalListViewHistory* historyItem=dynamic_cast<DalListViewHistory*>(di);
  if (historyItem) {
    setContents(new DalViewText(historyItem->attributable(),
				DalViewText::History,this));
    return;
  }
  
  DalListViewComment* commentItem=dynamic_cast<DalListViewComment*>(di);
  if (commentItem) {
    setContents(new DalViewText(commentItem->attributable(),
				DalViewText::Comment,this));
    return;
  }
  

  // default:
  hide();
}


void DalQuickView::setContents(QWidget* child)
{
  if (! child) return;

  if (_layout) delete _layout;
  if (_child)  delete _child;

  _layout=new QVBoxLayout(this);
  _child=child;



  _child->show();
  _layout->addWidget(_child);
  _layout->activate();

  show();
}
