// -*-C++-*-
//
// File:      DataSetBrowser.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 16:37:50 MET DST 2000

#include "DataSetBrowser.h"
#include "DalListView.h"
#include "DalQuickView.h"
#include "DalListViewItem.h"
#include "DalSelectionView.h"
#include "DalVisitedWidget.h"
#include "IconLibrary.h"
#include "Folder.h"

#include <GuiPreferences.h>

#include <qtoolbar.h>
#include <qtooltip.h>
#include <qtoolbutton.h>
#include <qsplitter.h>
#include <qpixmap.h>
#include <qdir.h>
#include <qapplication.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qstatusbar.h>

#include <errstr.h>

/* PATCH 1.28.4: remove trailing slash from environment!!*/
static QString jba_patch(const string& orig) {
  QString s=orig.c_str();
  if (s.length() <= 1) return s;
  if (s[s.length()-1] != '/') return s;
  return s.left(s.length()-1);
}

/* Experimental! */
class DataSetBrowserProperties
{
public:
  DataSetBrowserProperties() : _relative(false) {}
  bool            _relative; // path output
  QValueList<int> _horiz;    // split position
  QSize           _size;
};
DataSetBrowserProperties* DataSetBrowser::_property = 0;
Folder*                   DataSetBrowser::_root     = 0;

DataSetBrowser::DataSetBrowser(QWidget* parent, const char* name) : 
  QMainWindow(parent,name,WType_TopLevel|WType_Modal),
 _home(0),_ccf(0),_odf(0),_cwd(0),
 _result(Rejected)
{
  bool firstTime=false;
  firstTime=(! (_property || _root));
  if (!_property) _property = new DataSetBrowserProperties;
  if (!_root)     _root     = new Folder("/");
  statusBar(); // creates a status bar

  /*
    +----------+----------+
    |          |          |
    |  tree    |    flat  |
    |          |----------+
    |          |    view  |
    +----------+----------+
    |            cancel ok|
    +----------+----------+    
   */
  QFrame* frame=new QFrame(this);
  frame->setFrameStyle( QFrame::Panel | QFrame::Raised );
  setCentralWidget(frame);

  /*
    create the browser tree,contents and quick view
  */
  _splitWindow=new QSplitter(Qt::Horizontal, frame);
  _tree = new DalListView(_root,_splitWindow);

  QSplitter* vsplitter=new QSplitter(Qt::Vertical,_splitWindow);
  _contents = new DalListView(0,vsplitter);
  _selection= new DalSelectionView(vsplitter);
  _selection->hide();

  _quickView = new DalQuickView(vsplitter);
  _quickView->hide();


  DalListViewItem* current=_tree->currentItem();
  if (current) _contents->handleLeftClicked(current);

  //-> ToolBar
  _tools = new QToolBar("Browse",this);
  addToolBar(_tools);

  new QToolButton(IconLibrary::instance()->icon("Home.xpm"),
			 "Home","Go to Home directory",
			 this,SLOT(gotoHome()),_tools);
  new QToolButton(IconLibrary::instance()->icon("Odf.xpm"),
			 "ODF","Go to ODF directory",
			 this,SLOT(gotoOdf()),_tools);
  new QToolButton(IconLibrary::instance()->icon("Ccf.xpm"),
			 "CCF","Go to CCF directory",
			 this,SLOT(gotoCcf()),_tools);
  new QToolButton(IconLibrary::instance()->icon("Cwd.xpm"),
			 "Current","Go to current working directory",
			 this,SLOT(gotoCwd()),_tools);
  _tools->addSeparator();
  QToolButton* selBut=
    new QToolButton(IconLibrary::instance()->icon("Selected.xpm"),
		    "View all selected items",
		    "Show/hide selected items",
			 _selection,SLOT(pop()),_tools);
  selBut->setToggleButton(true);
  
  _tools->addSeparator();
  DalVisitedWidget* visit = new DalVisitedWidget(_tools);

  new QToolButton(IconLibrary::instance()->icon("FolderUp.xpm"),
			 "Go up one level","Go up one level",
			 _tree,SLOT(gotoParent()),_tools);

  QCheckBox* toggle=new QCheckBox("Relative path",frame);
  toggle->setChecked(_property->_relative);
  toggle->setEnabled(false);
  QToolTip::add(toggle,"Not implemented yet");

  _ok = new QPushButton("Ok",frame);
  _cancel = new QPushButton("Cancel",frame);


  QVBoxLayout* vbox=new QVBoxLayout(frame,5);
  vbox->addWidget(_splitWindow);

  QHBoxLayout* hbox=new QHBoxLayout(vbox,5);

  hbox->addWidget(toggle);
  hbox->addStretch(1); // adjust right
  hbox->addWidget(_cancel);
  hbox->addWidget(_ok);
 

  // tree->
  connect(_tree,SIGNAL(leftClicked(DalListViewItem *)),
	  visit,SLOT(add(DalListViewItem*)));
  connect(_tree,SIGNAL(leftClicked(DalListViewItem*)),
	  _contents,SLOT(handleDoubleClicked(DalListViewItem*)));
  connect(_tree,SIGNAL(doubleClicked(DalListViewItem*)),
	  _quickView,SLOT(contentsOf(DalListViewItem*)));

  // contents->
  /**
    Order is important!
    TODO: Better system for this, as this is sloppy....
   */
  connect(_contents,SIGNAL(doubleClicked(DalListViewItem*)),
	  _quickView,SLOT(contentsOf(DalListViewItem*)));
  connect(_contents,SIGNAL(doubleClicked(DalListViewItem*)),
	  _tree,SLOT(handleLeftClicked(DalListViewItem*)));
  connect(_contents,SIGNAL(leftClicked(DalListViewItem*)),
	  _contents,SLOT(handleLeftClicked(DalListViewItem*)));
  connect(_contents,SIGNAL(addSelection(DalListViewItem*)),
	  _selection,SLOT(add(DalListViewItem*)));
 
  // visit->
  connect(visit,SIGNAL(selected(DalListViewItem *)),
	  _tree,SLOT(jumpTo(DalListViewItem*)));
  connect(visit,SIGNAL(highlighted(const QString&)),
	  this,SLOT(message(const QString&)));

  // buttons->
  connect(_ok,SIGNAL(clicked()),this,SLOT(accept()));
  connect(_cancel,SIGNAL(clicked()),this,SLOT(reject()));
  connect(_selection,SIGNAL(filled(bool)),_ok,SLOT(setEnabled(bool)));

  setSelectable(DalListViewable::None);
  _ok->setEnabled(false);
  setPreferences(GuiPreferences::instance());

  if (!firstTime) {
    resize(_property->_size);
    _splitWindow->setSizes(_property->_horiz);
  }
  else {
    resize(sizeHint());
  }
}

DataSetBrowser::~DataSetBrowser()
{
  _property->_size=size();
  _property->_horiz=_splitWindow->sizes();
}


vector<string> DataSetBrowser::selection()
{
  vector<string> sel;
  QStringList qsel=_selection->selection();
  for (QStringList::Iterator it=qsel.begin();it!=qsel.end();it++)
    sel.push_back((*it).latin1());
  return sel;
}

void DataSetBrowser::setSelection(const vector<string>& s)
{
  for (vector<string>::const_iterator it=s.begin();it!=s.end();it++)
    openQualifiedName((*it).c_str(),false,true);
}


void DataSetBrowser::openQualifiedName(const QString& n, bool root, bool op)
{
  
  /* 'n' can be:
     - relative/absolute
     - file/dir/"qualified dal object"
     So make sure we can read it!
  */
  QString s(QDir::cleanDirPath(n));
  {
    QFileInfo f(s);
    s=f.absFilePath();
  }
  
  if (DalListViewItem* item=_tree->openQualifiedName(s)) {
    if (root) {
      item=item->clone(_tree);
      _tree->setOpen(_tree->firstChild(),false);
    }
    _tree->setOpen(item,op);
    _tree->setSelected(item,true);
    _tree->ensureItemVisible(item);

    /* determine whether we have found it in the tree*/
    QString qN(item->qualifiedName());
    if (qN != s) {
      if (qN.length() < s.length()) { // possible non-expandable child?
	item=_contents->firstChild();
	while(item){
	  if (item->qualifiedName() == s) break;
	  item=item->nextSibling();
	}
      }
      /* else the user specified something like "foo:", that is expanded to
	 the first entry "foo:bar"
       */
    }

    // put it into the bin ;-)
    if (item) {
      int t=_contents->selectable();
      if ( item->type() && t && ((t|item->type()) == t) ) 
	_selection->add(item);
    }

  }
}

void DataSetBrowser::setSelectable(int t)
{
  _contents->setSelectable(t);
  if (t == DalListViewable::None) {
    _ok->hide();
    _cancel->hide();
  } else {
    _ok->show();
    _cancel->show();
  }
}

void DataSetBrowser::setMultiSelection(bool b)
{
  _selection->setMultiSelection(b);
}

void DataSetBrowser::gotoHome()
{
  if (!_home) return;
  _tree->setSelected(_home,true);
  _tree->ensureItemVisible(_home);
}

void DataSetBrowser::gotoOdf()
{
  if (!_odf) return;
  _tree->setSelected(_odf,true);
  _tree->ensureItemVisible(_odf);
}

void DataSetBrowser::gotoCcf()
{
  if (!_ccf) return;
  _tree->setSelected(_ccf,true);
  _tree->ensureItemVisible(_ccf);
}

void DataSetBrowser::gotoCwd()
{
  if (!_cwd) return;
  _tree->setSelected(_cwd,true);
  _tree->ensureItemVisible(_cwd);
}

void DataSetBrowser::setPreferences(GuiPreferences* pref)
{
  delete _home;_home=0;
  delete _ccf; _ccf=0;
  delete _cwd; _cwd=0;
  delete _odf; _odf=0;

  Parameter* p=pref->getParameter("home");
  if (p) {
    QString s=jba_patch(p->stringValue());
    DalListViewItem* l=_tree->openQualifiedName(s);
    if (l) {
      if (l->qualifiedName() == s) _home=l;
    }
  }

  p=pref->getParameter("ccf");
  if (p) {
    QString s=jba_patch(p->stringValue());
    DalListViewItem* l=_tree->openQualifiedName(s);
    if (l && l->qualifiedName() == s) _ccf=l;
    else if (l) {
      l->setOpen(true);
      l->openChildren(_contents);
      DalListViewItem* c=_contents->openQualifiedName(s);
      
      if (c&& c->qualifiedName() == s) l->insertItem(_ccf=c);
    }
  }

  p=pref->getParameter("odf");
  if (p) {
    QString s=jba_patch(p->stringValue());
    DalListViewItem* l=_tree->openQualifiedName(s);
    if (l && l->qualifiedName() == s) _odf=l;
    else if (l) {
      l->setOpen(true);
      l->openChildren(_contents);
      DalListViewItem* c=_contents->openQualifiedName(s);
      
      if (c&& c->qualifiedName() == s) l->insertItem(_odf=c);
    }
  }

  p=pref->getParameter("current");
  if (p) {
    QString s=jba_patch(p->stringValue());
    DalListViewItem* l=_tree->openQualifiedName(s);
    if (l) {
      if (l->qualifiedName() == s) _cwd=l;
    }
  }

  /*
  DalListViewItem* l=0;
  if (_home) {
    l=_home=_home->clone(_tree);
    _home->setPixmap(0,IconLibrary::instance()->icon("Home.xpm"));
  }
  else errstr<<"Invalid HOME directory ignored"
	     <<Sas::warning("InvalidHomeDir");

  if (_ccf)  {
    l=_ccf=_ccf->clone(_tree);
    //_ccf->setPixmap(0,IconLibrary::instance()->icon("Ccf.xpm"));
    _ccf->setText(0,"CCF");
  }
  else errstr<<"Invalid CCF directory ignored"
	     <<Sas::warning("InvalidCcfDir");

  if (_odf)  {
    l=_odf=_odf->clone(_tree);
    _odf->setPixmap(0,IconLibrary::instance()->icon("Odf.xpm"));
  }
  else errstr<<"Invalid ODF directory ignored"
	     <<Sas::warning("InvalidOdfDir");

  if (_cwd)  {
    l=_cwd=_cwd->clone(_tree);
    _cwd->setPixmap(0,IconLibrary::instance()->icon("Cwd.xpm"));
  }
  else errstr<<"Invalid current directory ignored"
	     <<Sas::warning("InvalidCwdDir");

  if (l) {
    _tree->setOpen(_tree->firstChild(),false);
    _tree->setOpen(l,true);
    _tree->setSelected(l,true);
    _tree->ensureItemVisible(l);
  }
  */
  if (_cwd) {
    _tree->ensureItemVisible(_cwd);
    _tree->setSelected(_cwd,true);
  }
  
}

int DataSetBrowser::exec()
{
  show();
  qApp->enter_loop();
  return _result;
}

void DataSetBrowser::finish(ExitCode r)
{
  hide();
  _result=r;
  qApp->exit_loop();
}

void DataSetBrowser::accept()
{
  finish(Accepted);
}

void DataSetBrowser::reject()
{
  finish(Rejected);
}

void DataSetBrowser::closeEvent(QCloseEvent *e)
{
  e->accept();
  reject();
}

void DataSetBrowser::relative(bool b)
{
  _property->_relative=b;
}

void DataSetBrowser::message(const QString& m)
{
  statusBar()->message(m,1000);
}
