// -*-C++-*-
//
// File:      Folder.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:40:55 MET DST 2000

#include "Folder.h"
#include <Dal.h>

#include <qdir.h>
#include <qfile.h>
#include <qfileinfo.h>

#include <fstream>
#include <iostream>

Folder::Folder(const QString& name,Folder* parent) :
  _parsed(false),_readable(false),_name(name),_parent(parent)
{
  _folders.setAutoDelete(true);
  _files.setAutoDelete(true);
  _readable=QDir(QDir::cleanDirPath(qualifiedName())).isReadable();
}

Folder::~Folder()
{
}

void Folder::parse()
{
  if (_parsed) return;
  _parsed=true;

  if (!_readable) return;

  QDir thisDir( QDir::cleanDirPath(qualifiedName()));
  /*
  std::cerr << "parse:" << thisDir.absPath() << std::endl;
  */
  const QFileInfoList * entries = thisDir.entryInfoList();
  if ( !entries ) return;

  QFileInfoListIterator it( *entries);
  QFileInfo * entry;
  while( (entry=it.current()) != 0 ) {
    ++it;
    if ( entry->fileName() == "." || entry->fileName() == ".." )
      ; // nothing
    else if ( entry->isDir() ) {
      /*
      std::cerr << " dir:" << entry->fileName() << std::endl;
      */
      _folders.append(new Folder(entry->fileName(), this));
    }
    else {
      QString file(qualifiedName());
      file.append( "/" );
      file.append( entry->fileName() );
      
      _files.append(new AnyFile(entry->fileName(),this));   
    }
  }
}

QString Folder::qualifiedName()
{
  QString s;
  if ( _parent ) {
    s = _parent->qualifiedName();
    s.append( "/" );
    s.append( _name );

    s=QDir::cleanDirPath(s);
  } else {
    s = _name;
  }
  return s;
}
