/*****************************************************************************
 *
 *  AngleListParamWidget.cc                     XMM Science Analysis Subsystem
 *
 *  Widgets for editting angle list parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleListParamWidget.cc,v 1.4 2001/05/10 13:03:47 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleListParamWidget.h"
#include <iostream>

#include <qtooltip.h>


//================================================================
//  Class AngleListParamWidget
//================================================================

AngleListParamWidget::AngleListParamWidget(AngleListParameter* par,
					   QWidget* parent)
  : MultiAngleListEdit(parent)
{
    _par = par;
    Optional<double> min = _par->minValue();
    Optional<double> max = _par->maxValue();
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));
    connect(this, SIGNAL(modeChanged(AngleFormatter::AngleMode)),
            SLOT(modeChanged(AngleFormatter::AngleMode)));

    updateView();
}

AngleListParamWidget::~AngleListParamWidget()
{
    _par->deleteView(this);
}

void AngleListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void AngleListParamWidget::updateView()
{
    setMode(_par->getMode());
    setValue(_par->realListValue());
}

void AngleListParamWidget::modeChanged(AngleFormatter::AngleMode mode)
{
    _par->setMode(mode);
}
