/*****************************************************************************
 *
 *  AngleParamWidget.cc                         XMM Science Analysis Subsystem
 *
 *  Widget for editting angle parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleParamWidget.cc,v 1.5 2001/05/10 13:03:47 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleParamWidget.h"  // Application headers
#include "AngleParameter.h"
#include <Optional.h>

#include <iostream>          // C++ headers
#include <string>

#include <qtooltip.h>          // Qt headers


//================================================================
//  Class AngleParamWidget
//================================================================

AngleParamWidget::AngleParamWidget(AngleParameter* par, QWidget* parent)
  : MultiAngleEdit(parent)
{
    _par = par;
    Optional<double> min  = _par->minValue();
    Optional<double> max  = _par->maxValue();
    string prompt         = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged(double)), 
	    this, SLOT(valueChanged(double)));
    connect(this, SIGNAL(modeChanged(AngleFormatter::AngleMode)),
            SLOT(modeChanged(AngleFormatter::AngleMode)));

    updateView();
}

AngleParamWidget::~AngleParamWidget()
{
    _par->deleteView(this);
}

void AngleParamWidget::valueChanged(double value)
{
    _par->setValue(value);
}

void AngleParamWidget::updateView()
{
    setMode(_par->getMode());
    setValue(_par->realValue());
}

void AngleParamWidget::modeChanged(AngleFormatter::AngleMode mode)
{
    _par->setMode(mode);
}
