/*****************************************************************************
 *
 *  IntListParamWidget.cc                       XMM Science Analysis Subsystem
 *
 *  Widgets for editting list parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntListParamWidget.cc,v 1.6 2001/05/10 13:03:48 jbakker Exp $
 *
 *****************************************************************************/

#include "IntListParamWidget.h"  // Application headers
#include "IntListParameter.h"
#include <Optional.h>

#include <iostream>           // C++ headers
#include <string>
#include <vector>

#include <qtooltip.h>           // Qt headers


//================================================================
//  Class IntListParamWidget
//================================================================

IntListParamWidget::IntListParamWidget(IntListParameter* par, QWidget* parent)
  : IntegerListEdit(parent)
{
    _par = par; 
    Optional<int> min = _par->minValue();
    Optional<int> max = _par->maxValue();
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));

    updateView();
}

IntListParamWidget::~IntListParamWidget()
{
    _par->deleteView(this);
}

void IntListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void IntListParamWidget::updateView()
{
    setValue(_par->intListValue());
}
