/*****************************************************************************
 *
 *  ParamDialog.h                               XMM Science Analysis Subsystem
 *
 *  Parameter Dialog for the SAS GUI
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ParamDialog.h,v 1.9 2001/06/07 10:28:05 jbakker Exp $
 *
 *****************************************************************************/

#ifndef PARAMDIALOG_H
#define PARAMDIALOG_H

#include "GuiConst.h"          // Application headers
#include "ParameterInfo.h"
#include "Layout.h"
#include "OnDemandScrollView.h"

#include <qdialog.h>            // Qt headers
#include <qframe.h>
#include <qpushbutton.h>
#include <qstring.h>


//================================================================
//  Class ParamDialog
//================================================================

class ParamDialog : public QDialog, private GuiConst
{
    Q_OBJECT

public:

    // Constructors and destructors
    ParamDialog(ParameterInfo* info, QWidget *parent=0, 
		const char *name=0, bool useTabs=true,
		const char* okButton="Run",
		const char* lytFileName=0);
    ~ParamDialog();

private slots:

    // Button actions
    void run();
    void revertToDefault();

private:

    // Layout
    Layout* createLayout(bool useTabs, const char* lytFileName=0);
    Layout* createColumnLayout();
    Layout* createTabbedLayout(int maxPerTab);

   // Disabled copy constructor and operator=
    ParamDialog(const ParamDialog&) : QDialog() {}
    ParamDialog& operator=(const ParamDialog&) {return *this;}

    // Member data
    ParameterInfo*      _info;
    ParameterInfo*      _originalInfo;
    QWidget*            _canvas;
    Layout*             _layout;

    // Layout constants
    static const int maxWidth  = 600;
    static const int maxHeight = 700;
    static const int border    = 7;     // Border width
    static const int bw        = 60;    // Button width
    static const int bh        = 30;    // Button height
};

#endif
