/*****************************************************************************
 *
 *  PopupParamWidget.cc                         XMM Science Analysis Subsystem
 *
 *  String widget which pops up a browser dialog
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: PopupParamWidget.cc,v 1.10 2001/05/10 13:03:49 jbakker Exp $
 *
 *****************************************************************************/

#include "PopupParamWidget.h"      // Application headers
#include "StringParameter.h"

#include <iostream>              // C++ headers
#include <string>
#include <strstream>

#include <qlineedit.h>             // Qt headers
#include <qtooltip.h>
#include <qpushbutton.h>
#include <qwidget.h>


//================================================================
//  Abstract class PopupParamWidget
//================================================================

PopupParamWidget::PopupParamWidget(StringParameter* par, QWidget* parent)
  : QWidget(parent)
{
    _itype = DalListViewable::None;

    _par = par;
    string prompt = _par->prompt();

    _edit = new QLineEdit(this);
    if(prompt.length()>0)
        QToolTip::add(_edit,prompt.c_str());

    connect(_edit, SIGNAL(textChanged(const QString&)), 
	    this, SLOT(valueChanged(const QString&)));

    _button = new QPushButton(this);
    _button->setAutoDefault(false);
    _button->setText("..");
    QToolTip::add(_button,(string("Select ") + _par->getTypeName() + "...").c_str());

    connect(_button, SIGNAL(clicked()),this, SLOT(popupDialog()));

    updateView();
}

PopupParamWidget::~PopupParamWidget()
{
    _par->deleteView(this);
}

void PopupParamWidget::resizeEvent(QResizeEvent*)
{
    int w = width();
    int h = height();
    int bw = 16;
    
    _edit->setGeometry(0,0,w-bw,h);
    _button->setGeometry(w-bw,0,bw,h);
}

void PopupParamWidget::valueChanged(const QString& value)
{
    _par->setValue(value);
}

void PopupParamWidget::updateView()
{
    setText((_par->stringValue()).c_str());
}

void PopupParamWidget::setEnabled(bool enable)
{
    _edit->setEnabled(enable);
    _button->setEnabled(enable);
}

void PopupParamWidget::setText(const char* text)
{
    if(QString(text) != _edit->text())
        _edit->setText(text);
}
