/*****************************************************************************
 *
 *  RealParamWidget.cc                          XMM Science Analysis Subsystem
 *
 *  Widget for editting real parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealParamWidget.cc,v 1.6 2001/05/10 13:03:50 jbakker Exp $
 *
 *****************************************************************************/

#include "RealParamWidget.h"  // Application headers
#include "RealParameter.h"
#include <Optional.h>

#include <iostream>        // C++ headers
#include <string>

#include <qtooltip.h>        // Qt headers


//================================================================
//  Class RealParamWidget
//================================================================

RealParamWidget::RealParamWidget(RealParameter* par, QWidget* parent)
: DoubleEdit(parent)
{
    _par = par;
    Optional<double> min  = _par->minValue();
    Optional<double> max  = _par->maxValue();
    string prompt         = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged(double)), 
	    this, SLOT(valueChanged(double)));

    updateView();
}

RealParamWidget::~RealParamWidget()
{
    _par->deleteView(this);
}

void RealParamWidget::valueChanged(double value)
{
    _par->setValue(value);
}

void RealParamWidget::updateView()
{    
    setValue(_par->realValue());
}
