/*****************************************************************************
 *
 *  StringListParamWidget.cc                    XMM Science Analysis Subsystem
 *
 *  Widgets for editting string list parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringListParamWidget.cc,v 1.6 2001/05/10 13:03:50 jbakker Exp $
 *
 *****************************************************************************/

#include "StringListParamWidget.h"  // Application headers
#include "StringListParameter.h"
#include "StringChoiceListParameter.h"
//#include "SpecialStringListParameters.h"

#include <iostream>               // C++ headers
#include <string>
#include <vector>

#include <qtooltip.h>               // Qt headers


//================================================================
//  Class StringListParamWidget
//================================================================

StringListParamWidget::StringListParamWidget(StringListParameter* par, 
					     QWidget* parent)
  : StringListEdit(parent)
{
    _par = par;
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());

    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));

    updateView();
}


StringListParamWidget::~StringListParamWidget()
{
    _par->deleteView(this);
}

void StringListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void StringListParamWidget::updateView()
{
    setValue(_par->stringListValue());
}


//================================================================
//  Class StringChoiceParamWidget
//================================================================

StringChoiceListParamWidget::StringChoiceListParamWidget(StringChoiceListParameter* par,
							 QWidget* parent)
  : StringListEdit(parent)
{
    _par = par;
    vector<string> val = _par->stringListValue();
    string prompt = _par->prompt();

    setValue(val);

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());
    setChoices(_par->getChoices());
    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));
}

StringChoiceListParamWidget::~StringChoiceListParamWidget()
{
    _par->deleteView(this);
}

void StringChoiceListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void StringChoiceListParamWidget::updateView()
{
    setValue(_par->stringListValue());
}
