/*****************************************************************************
 *
 *  StringParamWidget.cc                        XMM Science Analysis Subsystem
 *
 *  Widget for editting string parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringParamWidget.cc,v 1.7 2001/05/10 13:03:50 jbakker Exp $
 *
 *****************************************************************************/

#include "StringParamWidget.h"  // Application headers
#include "StringParameter.h"

#include <iostream>           // C++ headers
#include <string>

#include <qtooltip.h>           // Qt headers
#include <qlineedit.h>


//================================================================
//  Class StringParamWidget
//================================================================

StringParamWidget::StringParamWidget(StringParameter* par, QWidget* parent)
  : QLineEdit(parent)
{
    _par = par;
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    connect(this, SIGNAL(textChanged(const QString&)), 
	    this, SLOT(valueChanged(const QString&)));

    updateView();
}

StringParamWidget::~StringParamWidget()
{
    _par->deleteView(this);
}

void StringParamWidget::valueChanged(const QString& value)
{
    _par->setValue(value);
}

void StringParamWidget::updateView()
{
    setText((_par->stringValue()).c_str());
}

void StringParamWidget::setText(const QString& s)
{
    if(s != text())
        QLineEdit::setText(s);
}
