/*****************************************************************************
 *
 *  TimeParamWidget.cc                          XMM Science Analysis Subsystem
 *
 *  Widget for editting time parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeParamWidget.cc,v 1.4 2001/05/10 13:03:50 jbakker Exp $
 *
 *****************************************************************************/

#include "TimeParamWidget.h"       // Application headers
#include <Optional.h>

#include <iostream>              // C++ headers
#include <string>

#include <qtooltip.h>              // Qt headers


//================================================================
//  Class TimeParamWidget
//================================================================

TimeParamWidget::TimeParamWidget(TimeParameter* par, QWidget* parent)
  : MultiTimeEdit(parent)
{
    _par = par;
    Optional<double> min  = _par->minValue();
    Optional<double> max  = _par->maxValue();
    string prompt         = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged(double)), 
	    this, SLOT(valueChanged(double)));
    connect(this, SIGNAL(modeChanged(TimeFormatter::TimeMode)),
            SLOT(modeChanged(TimeFormatter::TimeMode)));

    updateView();
}

TimeParamWidget::~TimeParamWidget()
{
    _par->deleteView(this);
}

void TimeParamWidget::valueChanged(double value)
{
    _par->setValue(value);
}

void TimeParamWidget::updateView()
{
    setMode(_par->getMode());
    setValue(_par->realValue());
}

void TimeParamWidget::modeChanged(TimeFormatter::TimeMode mode)
{
    _par->setMode(mode);
}
