/****************************************************************************
 *
 *  testFrameWidget.cc                        XMM Science Analysis Subsystem
 *
 *  Test program for FrameWidget
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testFrameWidget.cc,v 1.5 2001/05/10 13:03:50 jbakker Exp $
 *
 *****************************************************************************/

#include "EnableFrame.h"             // Application headers
#include "ChoiceFrame.h"
#include "LabelFrame.h"
#include "EnablingWidget.h"

#include <iostream>                // C++ headers

#include <qapp.h>                    // Qt headers
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qsize.h>
#include <qcombobox.h>


//================================================================
//  Class Demo
//================================================================

class Demo : public QWidget
{
public:
    Demo(QWidget* widget=0, const char* name=0);
};


Demo::Demo(QWidget* widget, const char* name)
  : QWidget(widget, name)
{
    QVBoxLayout* vbox = new QVBoxLayout(this,10);
 
    /*** EnableFrame (greying-out) ***/
    {
	QCheckBox* cb0 = new QCheckBox("enable",this);
        EnableFrame* frame = new EnableFrame(cb0,this);

	QWidget* col = new EnablingWidget(frame);
	col->setBackgroundColor(Qt::green);
	QVBoxLayout* box = new QVBoxLayout(col,5,-1);
	box->setResizeMode(QLayout::Minimum);
	QCheckBox* cb1 = new QCheckBox("hello",col);
	box->addWidget(cb1,0,Qt::AlignLeft);
	QCheckBox* cb2 = new QCheckBox("bye",col);
	box->addWidget(cb2,0,Qt::AlignLeft);
	box->activate();

	frame->setPage(col);
	vbox->addWidget(frame);
    }

    /*** ChoiceFrame ***/
    {
	QComboBox* combo = new QComboBox(this);
	combo->insertItem("red");
	combo->insertItem("green");
	combo->insertItem("blue");
	ChoiceFrame* frame = new ChoiceFrame(combo,this,"choice");

	QWidget* col1 = new EnablingWidget(frame);
	col1->setBackgroundColor(Qt::red);
	QVBoxLayout* box1 = new QVBoxLayout(col1,5,-1);
	box1->setResizeMode(QLayout::Minimum);
	QCheckBox* cb1 = new QCheckBox("hello",col1);
	box1->addWidget(cb1,0,Qt::AlignLeft);
	QCheckBox* cb2 = new QCheckBox("bye",col1);
	box1->addWidget(cb2,0,Qt::AlignLeft);
	box1->activate();
	frame->addPage(col1,"red");

	QWidget* col2 = new EnablingWidget(frame);
	col2->setBackgroundColor(Qt::green);
	QVBoxLayout* box2 = new QVBoxLayout(col2,5,-1);
	box2->setResizeMode(QLayout::Minimum);
	QCheckBox* cb3 = new QCheckBox("hello",col2);
	box2->addWidget(cb3,0,Qt::AlignLeft);
	box2->activate();
	frame->addPage(col2,"green");

	vbox->addWidget(frame);
    }

    /*** LabelFrame ***/
    {
        LabelFrame* frame = new LabelFrame("label",this);

	QWidget* col = new EnablingWidget(frame);
	col->setBackgroundColor(Qt::red);
	QVBoxLayout* box = new QVBoxLayout(col,5,-1);
	box->setResizeMode(QLayout::Minimum);

	QCheckBox* cb9 = new QCheckBox("hello",col);
	box->addWidget(cb9,0,Qt::AlignLeft);
	QCheckBox* cb10 = new QCheckBox("bye",col);
	box->addWidget(cb10,0,Qt::AlignLeft);

	box->activate();
	frame->setPage(col);
	vbox->addWidget(frame);
    }
}


//================================================================
//  Main program
//================================================================

int main(int argc, char **argv)
{
    // Create a window to display the widget
    QApplication app(argc, argv);
    QWidget mainWidget;
    mainWidget.resize(170,420);
    app.setMainWidget(&mainWidget);
    
    Demo* demo = new Demo(&mainWidget);
    QVBoxLayout* vbox = new QVBoxLayout(&mainWidget, 10);
    QHBoxLayout* hbox = new QHBoxLayout();
    vbox->addLayout(hbox);
    vbox->addStretch(1);

    hbox->addWidget(demo);
    hbox->addStretch(1);
    mainWidget.adjustSize();

    mainWidget.show();
    return app.exec();
}
