/*****************************************************************************
 *
 *  AngleEdit.cc                                XMM Science Analysis Subsystem
 *
 *  Qt widget for editing angles
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleEdit.cc,v 1.8 2001/05/10 13:03:51 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleEdit.h"

#include <qregexp.h>
#include <qstring.h>

#include <strstream>
#include <iomanip>

#include <cmath>
#include <cstdlib>


//================================================================
//  Class AngleEdit
//================================================================

/*** Constructor ***/

AngleEdit::AngleEdit(QWidget *parent, const char *name)
  : DoubleEdit(parent, name)
{
  QSize sz = minimumSizeHint();
  QFontMetrics fm(font());
  sz.setWidth(fm.maxWidth() * 8 + sz.width()-fm.maxWidth());
  
  setFixedSize(sz);

  setRange(-360,360);
  _mode = AngleFormatter::Degrees;
}


/*** Set the mode (Degrees, DMS or HMS) ***/

void AngleEdit::setMode(AngleFormatter::AngleMode mode)
{
    if(mode != _mode)
    {
        _mode = mode;
        setTextToValue();
    }
}


/*** Set widget text to current value ***/

void AngleEdit::setTextToValue()
{
    AngleFormatter formatter(_mode);
    setText(formatter.asString(_value,':').c_str());
}


/*** Parse string and set value ***/

void AngleEdit::setValueToText()
{
    double value = 0.0;
    AngleFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)text(), value, ':');

    if(ok && _value != value)
    {
        _value = value;
	emit valueChanged(_value);
    }
}


/*** Test the hard constraint - valid syntax ***/

bool AngleEdit::isValid()
{
    bool valid = false;
    
    switch(_mode)
    {
        case AngleFormatter::Degrees: {
            valid = DoubleEdit::isValid();
	    break;
	}
	
        case AngleFormatter::DMS:
	case AngleFormatter::HMS: {
            QRegExp expr("^ *-?[0-9]*:[0-5]?[0-9]?:[0-9]*[.]?[0-9]* *$");
	    int len = 0;
	    bool ok = expr.match(text(), 0, &len) == 0;
	    valid = ok && (len == (int)QString(text()).length());
	    break;
	}
    }
    return valid;
}


/*** Test the soft constraint - value in range ***/

bool AngleEdit::isInRange()
{
    double value = 0.0;

    AngleFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)text(), value, ':');
    ok &= isValidValue(value);
    
    return ok;
}

