/*****************************************************************************
 *
 *  AngleListEdit.cc                            XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleListEdit.cc,v 1.2 2001/05/10 13:03:51 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleListEdit.h"
#include "StringFns.h"

#include <qstring.h>
#include <qregexp.h>

#include <iostream>
#include <string>
#include <strstream>

#include <cmath>



//================================================================
//  Class AngleListEdit
//================================================================

/*** Constructor ***/

AngleListEdit::AngleListEdit(QWidget *parent, const char *name)
  : DoubleListEdit(parent, name)
{
      setRange(-360,360);
      _mode = AngleFormatter::Degrees;
}


/*** Set the mode (Degrees, DMS or HMS) ***/

void AngleListEdit::setMode(AngleFormatter::AngleMode mode)
{
    if(mode != _mode)
    {
        _mode = mode;
        setTextToValue();
    }
}

/*** Set widget text to current value ***/

void AngleListEdit::setTextToValue()
{
    strstream ostr;
    vector<double>::const_iterator it = _value.begin();
    if(it != _value.end())
        ostr << angleAsString(*it++);
    while(it != _value.end())
        ostr << ' ' << angleAsString(*it++);
    ostr << ends;

    setText(ostr.str());
    delete ostr.str();
}


/*** Format a single angle as a string ***/

string AngleListEdit::angleAsString(double angle)
{
    AngleFormatter formatter(_mode);
    return formatter.asString(angle,':');
}


/*** Parse a single angle ***/

bool AngleListEdit::parseItem(const QString& str, double& result)
{
    double value = 0.0;
    AngleFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)str, value, ':');

    if(ok)
        result = value;

    return ok;
}


/*** Test the hard constraint - valid syntax ***/

bool AngleListEdit::isValid()
{
    return true;
}


/*** Test the soft constraint - value in range ***/

bool AngleListEdit::isInRange()
{
    list<string> tokens = StringFns::splitString(string(text())," ");

    bool ok = true ;
    vector<double> values;
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString s = (*it++).c_str();
        if(s.length() != 0)     // Don't convert spaces
	    ok &= tokenInRange(s);
    }
    return ok;
}


bool AngleListEdit::tokenInRange(const char* str)
{
    double value = 0.0;

    AngleFormatter formatter(_mode);
    bool ok = formatter.parse(str, value, ':');
    ok &= isValidValue(value);
    
    return ok;
}
