/*****************************************************************************
 *
 *  DoubleListEdit.cc                           XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: DoubleListEdit.cc,v 1.7 2001/05/10 13:03:51 jbakker Exp $
 *
 *****************************************************************************/

#include <values.h>              // C headers

#include <iostream>            // C++ headers
#include <strstream>
#include <vector>

#include <qwidget.h>             // Qt headers
#include <qregexp.h>

#include "DoubleListEdit.h"      // Application headers
#include "StringFns.h"


//================================================================
//  Class DoubleListEdit
//================================================================

/*** Constructor ***/

DoubleListEdit::DoubleListEdit(QWidget *parent, const char *name)
  : ValidatedEdit(parent, name)
{
    setRange(-MAXDOUBLE, MAXDOUBLE);
    setTextToValue();              // Update widget
}


/***  Return the latest valid value ***/

vector<double> DoubleListEdit::value() const
{
    return _value;
}


/*** Set the value and update display. ***/

void DoubleListEdit::setValue(vector<double> value)
{
    if(value != _value)
    {
        _value = value;
	setTextToValue();          // Update widget
    }
}


/*** Set widget text to current value ***/

void DoubleListEdit::setTextToValue()
{
  QString txt("");
  QString s;
  for (vector<double>::const_iterator it = _value.begin();
       it != _value.end();it++)
    {
      s.setNum(*it,'g',12);
      if (!txt.isEmpty()) txt += ' ';
      txt +=s;
    }
  setText(txt);
}


/*** Parse string and set value ***/

void DoubleListEdit::setValueToText()
{
    list<string> tokens = StringFns::splitStringList(string(text()));

    bool ok = true ;
    vector<double> values;
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString s = (*it++).c_str();
        if(s.length() != 0)            // Don't convert spaces
        {
	    double val = 0.0;
	    ok &= parseItem(s, val);
            values.push_back(val);
        }
    }

    if(ok && (values != _value))
    {
        _value = values;
	emit valueChanged();
    }
}


/*** Parse a single value ***/

bool DoubleListEdit::parseItem(const QString& str, double& result)
{
    bool ok = false;
    double value = str.toDouble(&ok);
    if(ok)
        result = value;

    return ok;
}


/*** Test the hard constraint - valid syntax ***/

bool DoubleListEdit::isValid()
{
    QRegExp expr("^ *-?[0-9]*[.]?[0-9]*[Ee]?[+-]?[0-9]* *$");
    bool ok = true;

    list<string> tokens = StringFns::splitString(string(text())," ");
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        string s = *it++;

	int len = 0;
	ok &= expr.match(s.c_str(), 0, &len) == 0;
	ok &= len == (int)s.length();
    }
    return ok;
}


/*** Test the soft constraint - value in range ***/

bool DoubleListEdit::isInRange()
{
    bool ok = true;

    list<string> tokens = StringFns::splitString(string(text())," ");
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString buff = (*it++).c_str();
	bool ok1 = false;
	double val = buff.toDouble(&ok1);
	ok &= ok1 && isValidValue(val);
    }
    return ok;
}
