/*****************************************************************************
 *
 *  LineBuffer.h                                XMM Science Analysis Subsystem
 *
 *  FIFO buffer for line-buffering text
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: LineBuffer.h,v 1.1 1999/10/18 07:47:03 jbrumfit Exp $
 *
 *****************************************************************************/

#ifndef LINEBUFFER_H
#define LINEBUFFER_H

#include <string>                // C++ headers

#include <qobject.h>             // Qt headers


//================================================================
//  Class LineBuffer
//
//  The line buffer provides a FIFO queue for line-buffering text.
//
//  Characters are appended to the buffer with 'append'. Each time
//  a complete line is ready, a 'line' signal is emitted'. The
//  resulting line does NOT have a final newline character. Note 
//  that a single 'append' message, may emit any number of lines
//  (0,1,2,..).
//
//  The contents of the buffer may be flushed by calling 'flush'.
//  This does not emit a signal if the buffer is empty.
//
//  Example:
//     LineBuffer buffer = new LineBuffer;
//     connect(buffer, SIGNAL(line(const char*)), SLOT(...));
//     ...
//     buffer.append("foo\nbar");
//     buffer.append(" bye");
//     buffer.flush();
//
//================================================================

class LineBuffer : public QObject
{
    Q_OBJECT

public:
    void LineBuffer::append(const char* s);
    void LineBuffer::flush();

signals:
    void line(const char* text);

private:
    // Member data
    string _buffer;
};

#endif
