/*****************************************************************************
 *
 *  MultiAngleListEdit.cc                       XMM Science Analysis Subsystem
 *
 *  Qt widget for editing angles, with button to choose mode
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: MultiAngleListEdit.cc,v 1.3 2001/01/02 09:53:05 ulammers Exp $
 *
 *****************************************************************************/

#include "MultiAngleListEdit.h"    // Application headers
#include <qlayout.h>               // Qt headers
#include <qcombobox.h>


//================================================================
//  Class MultiAngleListEdit
//================================================================

/*** Constructor ***/

MultiAngleListEdit::MultiAngleListEdit(QWidget *parent, const char *name)
  : QWidget(parent, name)
{
  _angleEdit = new AngleListEdit(this,"angle");
  _combo = new QComboBox(false,this,"AngleMode");
  _combo->insertItem("deg",0);
  _combo->insertItem("DMS",1);
  _combo->insertItem("HMS",2);

  // layout
  QHBoxLayout* box = new QHBoxLayout(this);
  box->addWidget(_angleEdit);
  box->addWidget(_combo);

  // signal-slots
  connect(_combo,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));
  connect(_angleEdit,SIGNAL(valueChanged()),
	  this,SIGNAL(valueChanged()));

  // set
  setMode(_angleEdit->mode());

}


/*** Destructor **/

MultiAngleListEdit::~MultiAngleListEdit()
{
}


/*** Return the latest valid value ***/

vector<double> MultiAngleListEdit::value() const
{
    return _angleEdit->value();
}


/*** Set the value and update display ***/

void MultiAngleListEdit::setValue(vector<double> angle)
{
    _angleEdit->setValue(angle);
}


/*** Set enabled state of widget ***/

void MultiAngleListEdit::setEnabled(bool enabled)
{
    _angleEdit->setEnabled(enabled);
    _combo->setEnabled(enabled);
}


/*** Set the mode ***/

void MultiAngleListEdit::setMode(AngleFormatter::AngleMode mode)
{
  int id=-1;
  switch(mode) {
  case AngleFormatter::Degrees: id=0; break;
  case AngleFormatter::DMS:     id=1; break;
  case AngleFormatter::HMS:     id=2; break;
  }
  if (id > -1) {
    _combo->setCurrentItem(id);
    _angleEdit->setMode(mode);
  }
}

/*** activate settings ***/

void MultiAngleListEdit::activateMode(int idx)
{
  AngleFormatter::AngleMode m = AngleFormatter::Degrees;
  switch (idx) {
  case 0: m = AngleFormatter::Degrees ; break;
  case 1: m = AngleFormatter::DMS     ; break;
  case 2: m = AngleFormatter::HMS     ; break;
  }
  _angleEdit->setMode(m);
  emit modeChanged(m);
}

