/*****************************************************************************
 *
 *  MultiTimeEdit.cc                           XMM Science Analysis Subsystem
 *
 *  Qt widget for editing Times, with button to choose mode
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: MultiTimeEdit.cc,v 1.4 2001/01/02 09:53:05 ulammers Exp $
 *
 *****************************************************************************/

#include "MultiTimeEdit.h"        // Application headers
#include <qlayout.h>               // Qt headers
#include <qcombobox.h>


//================================================================
//  Class MultiTimeEdit
//================================================================

/*** Constructor ***/

MultiTimeEdit::MultiTimeEdit(QWidget *parent, const char *name)
  : QWidget(parent, name)
{
  
  // init members
  _timeEdit = new TimeEdit(this,"Time");
  _combo = new QComboBox(false,this,"TimeMode");
  _combo->insertItem("MRT",0);
  _combo->insertItem("JD",1);
  _combo->insertItem("MJD",2);
  _combo->insertItem("CAL",3);
  _combo->insertItem("FITS",4);
  
  // layout
  QHBoxLayout* box = new QHBoxLayout(this);
  box->addWidget(_timeEdit);
  box->addWidget(_combo);
  box->addStretch(1);

  // signal-slots
  connect(_combo,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));
  connect(_timeEdit,SIGNAL(valueChanged(double)),
	  this,SIGNAL(valueChanged(double)));

  // set
  setMode(_timeEdit->mode());
}


/*** Destructor **/

MultiTimeEdit::~MultiTimeEdit()
{
}


/*** Return the latest valid value ***/

double MultiTimeEdit::value() const
{
    return _timeEdit->value();
}


/*** Set the value and update display ***/

void MultiTimeEdit::setValue(double Time)
{
    _timeEdit->setValue(Time);
}


/*** Set enabled state of widget ***/

void MultiTimeEdit::setEnabled(bool enabled)
{
    _timeEdit->setEnabled(enabled);
    _combo->setEnabled(enabled);
}


/*** Set the mode ***/
void MultiTimeEdit::setMode(TimeFormatter::TimeMode mode)
{
  int id=-1;
  switch(mode) {
  case TimeFormatter::MRT: id=0; break;
  case TimeFormatter::JD: id=1; break;
  case TimeFormatter::MJD: id=2; break;
  case TimeFormatter::CAL: id=3; break;
  case TimeFormatter::FITS: id=4; break;
  }
  if (id > -1) {
    _combo->setCurrentItem(id);
    _timeEdit->setMode(mode);
  }
}

/*** activate settings ***/

void MultiTimeEdit::activateMode(int idx)
{
  TimeFormatter::TimeMode m = TimeFormatter::MRT;
  switch (idx) {
  case 0: m = TimeFormatter::MRT ; break;
  case 1: m = TimeFormatter::JD  ; break;
  case 2: m = TimeFormatter::MJD ; break;
  case 3: m = TimeFormatter::CAL ; break;
  case 4: m = TimeFormatter::FITS; break;
  }
  _timeEdit->setMode(m);
  emit modeChanged(m);
}
