/*****************************************************************************
 *
 *  RangeConstraint.h                           XMM Science Analysis Subsystem
 *
 *  Constrain value to lie within a range (closed interval)
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RangeConstraint.h,v 1.1 1999/06/24 09:24:33 jbrumfit Exp $
 *
 *****************************************************************************/

#ifndef RANGECONSTRAINT_H
#define RANGECONSTRAINT_H


//================================================================
//  Class RangeConstraint
//
//  Range constraint for types providing operator<= & operator>=
//================================================================

template <class T> class RangeConstraint
{
public:
    // Constraints
    void setMin(const T& min) { _min = min; }
    void setMax(const T& max) { _max = max; }
    void setRange(const T& min, const T& max) { _min = min; _max = max; }
    T min() const { return _min; }
    T max() const { return _max; }

    // Validation
    bool isValidValue(const T& value) const;

private:
    // Member data
    T _min;
    T _max;
};

/*** Test whether constraint is satisfied by value ***/

template <class T>
bool RangeConstraint<T>::isValidValue(const T& value) const
{
    return (value >= _min && value <= _max);
}

#endif
