/*****************************************************************************
 *
 *  SetConstraint.h                             XMM Science Analysis Subsystem
 *
 *  Constraint for value which must be member of a set
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SetConstraint.h,v 1.1 1999/06/24 09:24:34 jbrumfit Exp $
 *
 *****************************************************************************/

#ifndef SETCONSTRAINT_H
#define SETCONSTRAINT_H

#include <list>


//================================================================
//  Class SetConstraint
//
//  Constraint for value which must be member of a set
//================================================================

template <class T> class SetConstraint
{
public:
    // Set and get constraints
    void setChoices(const list<T>& choices) { _choices = choices; }
    void addChoice(const T& choice) { _choices.push_back(choice); }
    const list<T>& choices() const { return _choices; }

    // Validation
    bool isValidValue(const T& value) const;

private:
    // Member data
    list<T> _choices;
};


/*** Test whether constraint is satisfied by value ***/

template <class T>
bool SetConstraint<T>::isValidValue(const T& value) const
{
    bool valid = false;
    list<string>::const_iterator it = _choices.begin();
    if(it != _choices.end())
    {
        while(it != _choices.end())
        {
            if(*it++ == value)
                valid = true;
        }
    } else
        valid = true;   // OK if no choices defined
    return valid;
}

#endif
