/*****************************************************************************
 *
 *  TimeEdit.cc                                 XMM Science Analysis Subsystem
 *
 *  Qt widget for editing times
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeEdit.cc,v 1.3 2001/05/10 13:03:52 jbakker Exp $
 *
 *****************************************************************************/

#include "TimeEdit.h"

#include <qregexp.h>
#include <qstring.h>

#include <strstream>
#include <iomanip>

#include <cmath>
#include <cstdlib>


//================================================================
//  Class TimeEdit
//================================================================

/*** Constructor ***/

TimeEdit::TimeEdit(QWidget *parent, const char *name)
  : DoubleEdit(parent, name)
{
  QSize sz = minimumSizeHint();
  QFontMetrics fm(font());
  sz.setWidth(fm.width("2000-02-22T00:00:00.000")+sz.width()-fm.maxWidth());
  
  setFixedSize(sz);

  _mode = TimeFormatter::MRT;
}


/*** Set the mode (Degrees, DMS or HMS) ***/

void TimeEdit::setMode(TimeFormatter::TimeMode mode)
{
    if(mode != _mode)
    {
        _mode = mode;
        setTextToValue();
    }
}


/*** Set widget text to current value ***/

void TimeEdit::setTextToValue()
{
    TimeFormatter formatter(_mode);
    setText(formatter.asString(_value).c_str());
}


/*** Parse string and set value ***/

void TimeEdit::setValueToText()
{
    double value = 0.0;
    TimeFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)text(), value);

    if(ok && _value != value)
    {
        _value = value;
	emit valueChanged(_value);
    }
}


/*** Test the hard constraint - valid syntax ***/

bool TimeEdit::isValid()
{
//      bool valid = false;
    
//      switch(_mode)
//      {
//          case TimeFormatter::Degrees: {
//              valid = DoubleEdit::isValid();
//  	    break;
//  	}
	
//          case TimeFormatter::DMS:
//  	case TimeFormatter::HMS: {
//              QRegExp expr("^ *-?[0-9]*:[0-5]?[0-9]?:[0-9]*[.]?[0-9]* *$");
//  	    int len = 0;
//  	    bool ok = expr.match(text(), 0, &len) == 0;
//  	    valid = ok && (len == (int)QString(text()).length());
//  	    break;
//  	}
//      }
//      return valid;

  return true;
}


/*** Test the soft constraint - value in range ***/

bool TimeEdit::isInRange()
{
    double value = 0.0;

    TimeFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)text(), value);
    ok &= isValidValue(value);
    
    return ok;
}

