/*****************************************************************************
 *
 *  TimeListEdit.cc                            XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists of times
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeListEdit.cc,v 1.2 2001/05/10 13:03:52 jbakker Exp $
 *
 *****************************************************************************/

#include "TimeListEdit.h"
#include "StringFns.h"

#include <qstring.h>
#include <qregexp.h>

#include <iostream>
#include <string>
#include <strstream>

#include <cmath>



//================================================================
//  Class TimeListEdit
//================================================================

/*** Constructor ***/

TimeListEdit::TimeListEdit(QWidget *parent, const char *name)
  : DoubleListEdit(parent, name)
{
      _mode = TimeFormatter::MRT;
}


/*** Set the mode (Degrees, DMS or HMS) ***/

void TimeListEdit::setMode(TimeFormatter::TimeMode mode)
{
    if(mode != _mode)
    {
        _mode = mode;
        setTextToValue();
    }
}

/*** Set widget text to current value ***/

void TimeListEdit::setTextToValue()
{
    strstream ostr;
    vector<double>::const_iterator it = _value.begin();
    if(it != _value.end())
        ostr << timeAsString(*it++);
    while(it != _value.end())
        ostr << ' ' << timeAsString(*it++);
    ostr << ends;

    setText(ostr.str());
    delete ostr.str();
}


/*** Format a single time as a string ***/

string TimeListEdit::timeAsString(double time)
{
    TimeFormatter formatter(_mode);
    string s = formatter.asString(time);
    if(_mode == TimeFormatter::CAL)
        return string("\"") + formatter.asString(time) + "\"";
    else
        return formatter.asString(time);
}


/*** Parse a single time ***/

bool TimeListEdit::parseItem(const QString& str, double& result)
{
    double value = 0.0;
    TimeFormatter formatter(_mode);
    bool ok = formatter.parse((const char*)str, value);

    if(ok)
        result = value;

    return ok;
}


/*** Test the hard constraint - valid syntax ***/

bool TimeListEdit::isValid()
{
    return true;
}


/*** Test the soft constraint - value in range ***/

bool TimeListEdit::isInRange()
{
    list<string> tokens = StringFns::splitStringList(string(text()));

    bool ok = true ;
    vector<double> values;
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString s = (*it++).c_str();
        if(s.length() != 0)     // Don't convert spaces
	    ok &= tokenInRange(s);
    }
    return ok;
}


bool TimeListEdit::tokenInRange(const char* str)
{
    double value = 0.0;

    TimeFormatter formatter(_mode);
    bool ok = formatter.parse(str, value);
    ok &= isValidValue(value);
    
    return ok;
}
