/****************************************************************************
 *
 *  testValidatedEdit.cc                       XMM Science Analysis Subsystem
 *
 *  Test program for ValidatedEdit widget
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testValidatedEdit.cc,v 1.6 2001/05/10 13:03:53 jbakker Exp $
 *
 *****************************************************************************/

#include "testValidatedEdit.h"       // Application headers

#include <iostream>                // C++ headers

#include <qapplication.h>            // Qt headers
#include <qlabel.h>
#include <qlayout.h>


//================================================================
//  Class Demo
//================================================================

Demo::Demo( QWidget *parent, const char *name )
    : QWidget( parent, name )
{
    initMetaObject();


    /*** Create layout managers ***/

    QVBoxLayout* vbox = new QVBoxLayout(this,10);
    QGridLayout* grid = new QGridLayout(11,2,10);
    vbox->addLayout(grid);
    grid->addColSpacing(0,60);
    int row = 0;


    /*** Create an IntegerEdit widget ***/

    _int1 = new IntegerEdit(this,"int1");
    _int1->setFixedSize(100,22);
    _int1->setRevertDelay(2000);
    _int1->setRange(20,140);
    _int1->setValue(42);
    connect(_int1,SIGNAL(valueChanged(int)),SLOT(intChanged(int)));    
    grid->addWidget(new QLabel("Integer",this),row,0);
    grid->addWidget(_int1,row++,1);


    /*** Create a DoubleEdit widget ***/

    _double = new DoubleEdit(this,"double",2.71828);
    _double->setFixedSize(100,22);
    //  _double->setRange(0,100);
    //    _double->setValue(3.14159);
    connect(_double,SIGNAL(valueChanged(double)),SLOT(doubleChanged(double)));
    grid->addWidget(new QLabel("Double",this),row,0);
    grid->addWidget(_double,row++,1);


    /*** Create another so we can test focus ***/

    _double2 = new DoubleEdit(this,"double2");
    _double2->setFixedSize(100,22);
    _double2->setRange(0,100);
    // This one has default value
    connect(_double,SIGNAL(valueChanged(double)),_double2,SLOT(setValue(double)));
    connect(_double2,SIGNAL(valueChanged(double)),SLOT(double2Changed(double)));
    grid->addWidget(new QLabel("Result",this),row,0);
    grid->addWidget(_double2,row++,1);


    /*** Create an AngleEdit widget ***/

    _angle = new AngleEdit(this,"angle");
    _angle->setFixedSize(100,22);
    _angle->setRange(0,100);
    _angle->setValue(2.72);
    connect(_angle,SIGNAL(valueChanged(double)),SLOT(angleChanged(double)));
    grid->addWidget(new QLabel("Angle",this),row,0);
    grid->addWidget(_angle,row++,1);


     /*** Create a BoolListEdit widget ***/

    _boolList = new BoolListEdit(this,"boollist");
    _boolList->setFixedSize(100,22);
    connect(_boolList,SIGNAL(valueChanged()),SLOT(boolListChanged()));  
    grid->addWidget(new QLabel("BoolList",this),row,0);
    grid->addWidget(_boolList,row++,1);


    /*** Create an IntegerListEdit widget ***/

    _intList = new IntegerListEdit(this,"intlist");
    _intList->setFixedSize(100,22);
    _intList->setRange(20,140);
    connect(_intList,SIGNAL(valueChanged()),SLOT(intListChanged()));  
    grid->addWidget(new QLabel("IntList",this),row,0);
    grid->addWidget(_intList,row++,1);


    /*** Create an DoubleListEdit widget ***/

    _doubleList = new DoubleListEdit(this,"intlist");
    _doubleList->setFixedSize(100,22);
    _doubleList->setRange(20,140);
    connect(_doubleList,SIGNAL(valueChanged()),SLOT(doubleListChanged()));  
    grid->addWidget(new QLabel("DoubleList",this),row,0);
    grid->addWidget(_doubleList,row++,1);


    /*** Create an AngleListEdit widget ***/

    _angleList = new AngleListEdit(this,"anglelist");
    _angleList->setFixedSize(100,22);
    _angleList->setRange(20,140);
    connect(_angleList,SIGNAL(valueChanged()),SLOT(angleListChanged()));  
    grid->addWidget(new QLabel("AngleList",this),row,0);
    grid->addWidget(_angleList,row++,1);


    /*** Create a StringListEdit widget ***/

    _stringList = new StringListEdit(this,"stringlist");
    _stringList->setFixedSize(100,22);
    connect(_stringList,SIGNAL(valueChanged()),SLOT(stringListChanged()));  
    grid->addWidget(new QLabel("StringList",this),row,0);
    grid->addWidget(_stringList,row++,1);


    /*** Create a choice-list widget ***/

    _choiceList = new StringListEdit(this,"choicelist");
    _choiceList->setFixedSize(100,22);
    _choiceList->addChoice("red");
    _choiceList->addChoice("blue");
    _choiceList->addChoice("green");
    connect(_choiceList,SIGNAL(valueChanged()),SLOT(choiceListChanged()));  
    grid->addWidget(new QLabel("ChoiceList",this),row,0);
    grid->addWidget(_choiceList,row++,1);


    /*** Create a MultiAngleEdit widget ***/

    _multiAngle = new MultiAngleEdit(this,"multiAngle");
    _multiAngle->setFixedSize(100,22);
    _multiAngle->setRange(-400,400);
    _multiAngle->setValue(1.59);
    connect(_multiAngle,SIGNAL(valueChanged(double)),
	    SLOT(multiAngleChanged(double)));
    grid->addWidget(new QLabel("Angle",this),row,0);
    grid->addWidget(_multiAngle,row++,1);

    
   /*** Create the buttons ***/

    QHBoxLayout* hbox = new QHBoxLayout();
    vbox->addLayout(hbox);

    _disableButton = new QPushButton("Disable", this, "disableButton");
    _disableButton->setFixedSize(80,30);
    connect(_disableButton, SIGNAL(clicked()), SLOT(disableButtonClicked()) );
    hbox->addWidget(_disableButton,5,5);

    _quitButton = new QPushButton("Quit", this, "quitButton");
    _quitButton->setFixedSize(80,30);
    connect(_quitButton, SIGNAL(clicked()), qApp, SLOT(quit()));
    hbox->addWidget(_quitButton,5,5);
}


/*** Toggle enabled state of widgets ***/

void Demo::disableButtonClicked()
{
    bool enable = !_int1->isEnabled();

    _int1->setEnabled(enable);
    _double->setEnabled(enable);
    _double2->setEnabled(enable);
    _angle->setEnabled(enable);
    _boolList->setEnabled(enable);
    _intList->setEnabled(enable);
    _doubleList->setEnabled(enable);
    _angleList->setEnabled(enable);
    _stringList->setEnabled(enable);
    _choiceList->setEnabled(enable);
    _multiAngle->setEnabled(enable);

    if(enable)
        _disableButton->setText("Disable");
    else
	_disableButton->setText("Enable");
}


void Demo::intChanged(int n)
{
    cout << "int = " << n << endl;
}

void Demo::doubleChanged(double n)
{
    cout << "double = " << n << endl;
}

void Demo::double2Changed(double n)
{
    cout << "double2 = " << n << endl;
}

void Demo::angleChanged(double n)
{
    cout << "angle = " << n << endl;
}

void Demo::boolListChanged()
{
    cout << "boolList = ";
    vector<int> values = _boolList->value();
    vector<int>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << ' ' << *it++;
    cout << endl;
}

void Demo::intListChanged()
{
    cout << "intList = ";
    vector<int> values = _intList->value();
    vector<int>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << ' ' << *it++;
    cout << endl;
}

void Demo::doubleListChanged()
{
    cout << "doubleList = ";
    vector<double> values = _doubleList->value();
    vector<double>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << ' ' << *it++;
    cout << endl;
}

void Demo::angleListChanged()
{
    cout << "angleList = ";
    vector<double> values = _angleList->value();
    vector<double>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << ' ' << *it++;
    cout << endl;
}

void Demo::stringListChanged()
{
    cout << "stringList = |";
    vector<string> values = _stringList->value();
    vector<string>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << '|' << *it++;
    cout << '|' << endl;
}

void Demo::choiceListChanged()
{
    cout << "choiceList = |";
    vector<string> values = _choiceList->value();
    vector<string>::const_iterator it = values.begin();
    if(it != values.end())
        cout << *it++;
    while(it != values.end())
        cout << '|' << *it++;
    cout << '|' << endl;
}

void Demo::multiAngleChanged(double n)
{
    cout << "multiAngle = " << n << endl;
}


//================================================================
//  Main program
//================================================================

int main(int argc, char **argv)
{
    QApplication app(argc, argv);
    Demo mainWidget;
    app.setMainWidget(&mainWidget);
    mainWidget.show();
    return app.exec();
}
